@@ -29,6 +29,7 @@ class BloggerApplet(gnome.applet.Applet):
         self.__gobject_init__()
 
     def init(self):
+        self.set_applet_flags(gnome.applet.EXPAND_MINOR)
         self.toggle = gtk.ToggleButton()
         self.applet_tooltips = gtk.Tooltips()
         self.setup_menu_from_file (None, "GNOME_BlogApplet.xml",
@@ -47,26 +48,27 @@ class BloggerApplet(gnome.applet.Applet):
         
         self.show_all()
 
-        self.poster_window = aligned_window.AlignedWindow(self.toggle)
-        self.poster_window.set_modal(gtk.TRUE)
+        self.poster_window = aligned_window.AlignedWindow(self.toggle, self.get_orient)
         accel_group = gtk.AccelGroup()
         self.poster_window.add_accel_group(accel_group)
         self.prefs_key = self.get_preferences_key()
         print "Applet prefs located at %s" % (self.prefs_key)
-        self.poster = blog_poster.BlogPosterSimple(prefs_key=self.prefs_key, on_entry_posted=self._onEntryPosted)
+        self.poster = blog_poster.BlogPosterSimple(prefs_key=self.prefs_key,
+                                                   on_entry_posted=self._onEntryPosted,
+                                                   accel_group=accel_group)
         self.poster_window.add(self.poster)
         self.poster.show()
 
         client = gconf.client_get_default()
         value = client.get_bool(self.prefs_key + "/initialized")
-        if value == None or value == gtk.FALSE:
+        if value == None or value == False:
             self.poster._showPrefDialog()
 #            self._showPrefDialog()
-            client.set_bool(self.prefs_key + "/initialized", gtk.TRUE)
+            client.set_bool(self.prefs_key + "/initialized", True)
 
         self._createToolTip(client)
         
-        return gtk.TRUE
+        return True
     
     def _showAboutDialog(self, uicomponent, verb):
         gnome.ui.About(gnome_blog_globals.name, gnome_blog_globals.version, "Copyright 2003 Seth Nickell",
@@ -91,7 +93,7 @@ class BloggerApplet(gnome.applet.Applet):
             self.poster_window.hide()
 
     def _onEntryPosted(self):
-        self.toggle.set_active(gtk.FALSE)
+        self.toggle.set_active(False)
 
     def _onButtonPress(self, toggle, event):
         if event.button != 1:
