@@ -36,9 +36,9 @@ class BlogPoster(gtk.Frame):
         
         self.blogEntry   = rich_entry.RichEntry()
 
-	#if we are using gtkspell, attach it to the blogEntry
-	if use_gtkspell:
-		gtkspell.Spell(self.blogEntry)
+        #if we are using gtkspell, attach it to the blogEntry
+        if use_gtkspell:
+            self._attach_gtkspell()
 
         scroller         = gtk.ScrolledWindow()
         self.postButton  = gtk.Button(_("_Post Entry"))
@@ -69,21 +69,21 @@ class BlogPoster(gtk.Frame):
         self.prefs_button = gtk.Button(_("Preferences..."))
         self.prefs_button.connect("clicked", self._onPrefsButtonClicked)
 
-        buttonBox.pack_start(boldToggle, expand=gtk.FALSE)
-        buttonBox.pack_start(italicToggle, expand=gtk.FALSE)        
-        buttonBox.pack_start(linkButton, expand=gtk.FALSE)
-        buttonBox.pack_start(self.prefs_button, expand=gtk.FALSE)
+        buttonBox.pack_start(boldToggle, expand=False)
+        buttonBox.pack_start(italicToggle, expand=False)        
+        buttonBox.pack_start(linkButton, expand=False)
+        buttonBox.pack_start(self.prefs_button, expand=False)
             
         self.titleEntry = gtk.Entry()
 
         titleBox = gtk.HBox()
         titleBox.set_spacing(12)
-        titleBox.pack_start(gtk.Label(_("Title:")), expand=gtk.FALSE)
+        titleBox.pack_start(gtk.Label(_("Title:")), expand=False)
         titleBox.pack_start(self.titleEntry)
 
-        box.pack_start(titleBox)
+        box.pack_start(titleBox, expand=False)
         box.pack_start(scroller)
-        box.pack_start(buttonBox)
+        box.pack_start(buttonBox, expand=False)
 
         self.add(box)
         box.show_all()
@@ -118,17 +118,16 @@ class BlogPoster(gtk.Frame):
         #we must turn off the spell checker so as not to confuse
         #the markup to html converter
         if use_gtkspell:
-            spell = gtkspell.get_from_text_view(self.blogEntry)
-            spell.detach()
-        
+            self._detach_gtkspell()
+
         html_text = self.blogEntry.getHTML()
 
-	#turn spelling back on
+        #turn spelling back on
         if use_gtkspell:
-            gtkspell.Spell(self.blogEntry)
+            self._attach_gtkspell()
 
         print "Text is: {\n %s \n }\n" % (html_text)
-        title = self.titleEntry.get_text()
+        title = self.titleEntry.get_text().decode('utf-8')
 
         # Don't post silly blog entries like blank ones
         if not self._postIsReasonable(html_text):
@@ -161,11 +160,26 @@ class BlogPoster(gtk.Frame):
         # unreasonable
         if not text:
             hig_alert.reportError(_("Blog Entry is Blank"), _("No text was entered in the blog entry box. Please enter some text and try again"))
-            return gtk.FALSE
+            return False
         else:
-            return gtk.TRUE
+            return True
+
+    def _attach_gtkspell(self):
+        try:
+            gtkspell.Spell(self.blogEntry)
+        except:
+            # unable to initialise Spell object
+            # maybe there is no dictionary for $LANG installed
+            use_gtkspell = 0
+
+    def _detach_gtkspell(self):
+        try:
+            spell = gtkspell.get_from_text_view(self.blogEntry)
+            spell.detach()
+        except:
+            use_gtkspell = 0
 
 class BlogPosterSimple(BlogPoster):
-    def __init__(self, prefs_key="/apps/gnome-blog", on_entry_posted=None):    
-        BlogPoster.__init__(self,prefs_key,on_entry_posted)
+    def __init__(self, prefs_key="/apps/gnome-blog", on_entry_posted=None, accel_group=None):
+        BlogPoster.__init__(self, prefs_key, on_entry_posted, accel_group)
         self.prefs_button.hide_all();
