@@ -1,15 +1,16 @@
 import xmlrpclib
 import base64
 
-from gtk import TRUE, FALSE
 import gconf
 
+
 import gettext
 _ = gettext.gettext
 
 from gnomeblog import hig_alert
 from gnomeblog import bloggerAPI
 from gnomeblog import proxy
+from gnomeblog import blog
 
 class Blog(bloggerAPI.Blog):
     def __init__(self):
@@ -22,11 +23,11 @@ class Blog(bloggerAPI.Blog):
 
         if (base_url == None):
             hig_alert.reportError("Could not post Blog entry", "No XML-RPC server URL to post blog entries to is set, or the value could not be retrieved from GConf. Your entry will remain in the blogger window.")
-            return FALSE
+            return False
 
         blog_id  = client.get_string(gconf_prefix + "/blog_id")
 
-        success = TRUE
+        success = True
 
         #check for GNOME proxy configurations and use if required
         proxy_transport = proxy.GnomeProxyTransport(client)
@@ -40,10 +41,13 @@ class Blog(bloggerAPI.Blog):
             server.metaWeblog.newPost(blog_id, username, password, content, xmlrpclib.True)
         except xmlrpclib.Fault, e:
             hig_alert.handleBloggerAPIFault(e, "Could not post blog entry", username, blog_id, url)
-            success = FALSE
+            success = False
+        except xmlrpclib.ResponseError, e:
+            hig_alert.reportError("Could not post Blog entry", 'Received an invalid response: %s posting to URL %s.' % (hig_alert.italic(e), url))
+            success = False
         except xmlrpclib.ProtocolError, e:
             hig_alert.reportError("Could not post Blog entry", 'URL \'%s\' does not seem to be a valid bloggerAPI XML-RPC server. Web server reported: %s.' % (url, hig_alert.italic(e.errmsg)))
-            success = FALSE
+            success = False
 
         return success
 
@@ -54,7 +58,7 @@ class Blog(bloggerAPI.Blog):
 
         blog_id  = client.get_string(gconf_prefix + "/blog_id")
 
-        success = TRUE
+        success = True
         
         #check for GNOME proxy configurations and use if required
         proxy_transport = proxy.GnomeProxyTransport(client)
@@ -65,13 +69,15 @@ class Blog(bloggerAPI.Blog):
         content['type'] = mime_type
         content['bits'] = base64.encodestring(file_contents)
 
+        imageurl = None
+
         try:
-            server.metaWeblog.newMediaObject(blog_id, username, password, content)
+            imageurl = (server.metaWeblog.newMediaObject(blog_id, username, password, content))['url']
         except xmlrpclib.Fault, e:
             hig_alert.handleBloggerAPIFault(e, "Could not post Image", username, blog_id, url)
-            success = FALSE
         except xmlrpclib.ProtocolError, e:
             hig_alert.reportError("Could not post Blog entry", 'URL \'%s\' does not seem to be a valid bloggerAPI XML-RPC server. Web server reported: %s.' % (url, hig_alert.italic(e.errmsg)))
-            success = FALSE
-            
+
+        return imageurl
+    
 blog = Blog()
